import 'package:flutter/material.dart';
import '../marker_data.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';

class MapContainerWidget extends StatefulWidget {
  final List<MarkerTemplate> markerList;

  const MapContainerWidget({Key? key, required this.markerList}) : super(key: key);

  @override
  _MapContainerWidgetState createState() => _MapContainerWidgetState();
}

class _MapContainerWidgetState extends State<MapContainerWidget> {

  MarkerTemplate? selectedMarker;

  @override
  Widget build(BuildContext context) {
    double screenWidth = MediaQuery.of(context).size.width;
    double boxWidth = 0.9;
    double boxHeight = 1.5;

    return Column(
      children: [
        Container(
          width: screenWidth * boxWidth,
          height: screenWidth * boxHeight,
          color: Colors.blue,
          child: FlutterMap(
            options: MapOptions(
              center: LatLng(60.7666, 10.8471),
              zoom: 9.0,
            ),
            children: [
              TileLayer(
                urlTemplate: "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
                subdomains: const ['a', 'b', 'c'],
              ),
              MarkerLayer(
                markers: widget.markerList.map((MarkerTemplate markerTemplate) {
                  return Marker(
                    width: markerTemplate.size,
                    height: markerTemplate.size,
                    point: markerTemplate.location,
                    builder: (ctx) => GestureDetector(
                      onTap: () {
                        setState(() {
                          selectedMarker = markerTemplate;
                        });
                        // NB: temporary print
                        print('Icon tapped: ${selectedMarker?.size}');
                      },
                      child: Image.asset(
                        'assets/icons/circle-red.png',
                        // Path to your custom icon asset
                        color: markerTemplate.color,
                        width: markerTemplate.size,
                        height: markerTemplate.size,
                      ),
                    ),
                  );
                }).toList(),
              ),
              /*PolygonLayer(
                  polygons: [
                    Polygon(
                      points: [
                        LatLng(60.7600, 10.8000),
                        LatLng(60.7600, 11.0000),
                        LatLng(60.7000, 11.0000),
                        LatLng(60.7000, 10.8000),
                      ],
                      color: Colors.blue,
                      isFilled: true,
                    ),
                  ],
                ),*/
            ],
          ),
        ),
        const SizedBox(height: 30), // Padding between containers
        Container(
          width: screenWidth * boxWidth,
          height: screenWidth * boxHeight,
          color: const Color(0xFF64B5F6),
          child: Align(
            alignment: Alignment.topLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 20, left: 20), // Edge padding, text
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Text(
                    'Ice stats',
                    style: TextStyle(fontSize: 30, color: Colors.black),
                  ),
                  Text(
                    'Latitude: ${selectedMarker?.geoData.latitude}',
                    style: const TextStyle(fontSize: 20, color: Colors.black),
                  ),
                  Text(
                    'Longitude: ${selectedMarker?.geoData.longitude}',
                    style: const TextStyle(fontSize: 20, color: Colors.black),
                  ),
                ],
              ),
            ),
          ),
        ),
      ],
    );
  }
}
